@@ -78,13 +78,11 @@ class Exporter(LoggingConfigurable):
     export_from_notebook: str = None  # type:ignore[assignment]
 
     # Configurability, allows the user to easily add filters and preprocessors.
-    preprocessors: List[str] = List(
+    preprocessors: List[t.Any] = List(
         help="""List of preprocessors, by name or namespace, to enable."""
-    ).tag(  # type:ignore[assignment]
-        config=True
-    )
+    ).tag(config=True)
 
-    _preprocessors: List[str] = List()
+    _preprocessors: List[t.Any] = List()
 
     default_preprocessors: List[t.Any] = List(
         [
@@ -351,7 +349,7 @@ class Exporter(LoggingConfigurable):
         # Run each preprocessor on the notebook.  Carry the output along
         # to each preprocessor
         for preprocessor in self._preprocessors:
-            nbc, resc = preprocessor(nbc, resc)  # type:ignore[operator]
+            nbc, resc = preprocessor(nbc, resc)
             if not self.optimistic_validation:
                 self._validate_preprocessor(nbc, preprocessor)
 
