@@ -4,7 +4,7 @@ Converts links between notebooks to Latex cross-references.
 """
 import re
 
-from pandocfilters import RawInline, applyJSONFilters, stringify  # type:ignore[import]
+from pandocfilters import RawInline, applyJSONFilters, stringify  # type:ignore[import-untyped]
 
 
 def resolve_references(source):
